@@ -131,7 +131,7 @@ def get_courses(schedule):
     for semester in schedule:
         for course in schedule[semester]:
             capacity = course["sections"][0]["capacity"]
-            if capacity == 0:
+            if capacity in (0, None):
                 courses.append(course["course"]["code"])
 
     courses = list(dict.fromkeys(courses))
@@ -234,7 +234,7 @@ def model_1_output(input_file: dict) -> dict:
         if value[2] != []:
             summer_offerings.append(build_offering_dict(key, value[2], title))
 
-    print('Returning fomatted output')
+    print('Returning fomatted output', file=sys.stderr)
     return {"fall": fall_offerings,
             "spring": spring_offerings,
             "summer": summer_offerings}
@@ -244,12 +244,12 @@ def parse_output_for_backend(predictor_output: dict, schedule: dict, dummy: bool
         Helper.decompress_file('Output/dummy_out.json.bz2', 'Output/dummy_out.json')
         file = open('Output/dummy_out.json', 'r')
         dummy_output = json.load(file)
-        print('returning dummy')
+        print('returning dummy', file=sys.stderr)
         return(dummy_output)
     
     first_year_copy = []
     if(exists(COMPRESSED_NON_CORE_FIRST_YEAR_PATH)):
-        print("Extracting existing first year data ..")
+        print("Extracting existing first year data ..", file=sys.stderr)
         with open(NON_CORE_FIRST_YEAR_OUTPUT_PATH, 'wb') as new_file, bz2.BZ2File(COMPRESSED_NON_CORE_FIRST_YEAR_PATH, 'rb') as file:
             decompressor = bz2.BZ2Decompressor()
             for data in iter(lambda: file.read(100*1024), b''):
@@ -258,12 +258,12 @@ def parse_output_for_backend(predictor_output: dict, schedule: dict, dummy: bool
         data_file = open(NON_CORE_FIRST_YEAR_OUTPUT_PATH, 'r')
         first_year_copy = json.load(data_file)
     else:
-        print("Getting fresh copy of first year data ..")
+        print("Getting fresh copy of first year data ..", file=sys.stderr)
         first_year_copy = get_prev_year_course_data(2022)
     predictor_output.update(first_year_copy)
 
     for semester in schedule:
-        print(semester)
+        print(semester, file=sys.stderr)
         if(semester == "fall"):
             for course in schedule[semester]:
                 code = course["course"]["code"]
