@@ -1,5 +1,6 @@
 from inspect import CORO_SUSPENDED
 import numpy as np
+import sys
 from sklearn.linear_model import LinearRegression
 from c1algo2 import data
 from c1algo2.InputProcessor import DataProcessor
@@ -163,7 +164,7 @@ def forecast(historical_data, previous_enrollment, schedule):
 
     schedule = data.fill_capacities(schedule, outputDict, 2022)
 
-    print(outputDict)
+    print(outputDict, file=sys.stderr)
 
     return schedule
 
